# Summary of 7 files

### probably_ok in 6 LFNs

| Transform | LFN | Job ID | Site | Peak Mem | Log URL(s) | Occurrences |
| --------- | --- | ------ | ---- | -------- | ---------- | ----------- |
| `335424` | `LFN:/lhcb/LHCb/Collision25/B2OC.DST/00310455/0009/00310455_00095684_1.b2oc.dst` | 1218754724 | **LCG.IN2P3.fr** (3) | 3.4 GiB | [here](https://lhcb-productions.web.cern.ch/logs/?lfn=%2Flhcb%2FLHCb%2FCollision25%2FLOG%2F00335424%2F0000&task_name=00005041) [here](https://lhcb-productions.web.cern.ch/logs/?lfn=%2Flhcb%2FLHCb%2FCollision25%2FLOG%2F00335424%2F0000&task_name=00005027) [here](https://lhcb-productions.web.cern.ch/logs/?lfn=%2Flhcb%2FLHCb%2FCollision25%2FLOG%2F00335424%2F0000&task_name=00004018) | 3 / 3 |
|  | `LFN:/lhcb/LHCb/Collision25/B2OC.DST/00310455/0009/00310455_00097147_1.b2oc.dst` | 1218754724 | **LCG.IN2P3.fr** (3) | 3.4 GiB | [here](https://lhcb-productions.web.cern.ch/logs/?lfn=%2Flhcb%2FLHCb%2FCollision25%2FLOG%2F00335424%2F0000&task_name=00005041) [here](https://lhcb-productions.web.cern.ch/logs/?lfn=%2Flhcb%2FLHCb%2FCollision25%2FLOG%2F00335424%2F0000&task_name=00005027) [here](https://lhcb-productions.web.cern.ch/logs/?lfn=%2Flhcb%2FLHCb%2FCollision25%2FLOG%2F00335424%2F0000&task_name=00004018) | 3 / 3 |
|  | `LFN:/lhcb/LHCb/Collision25/B2OC.DST/00310455/0009/00310455_00097148_1.b2oc.dst` | 1218754724 | **LCG.IN2P3.fr** (3) | 3.4 GiB | [here](https://lhcb-productions.web.cern.ch/logs/?lfn=%2Flhcb%2FLHCb%2FCollision25%2FLOG%2F00335424%2F0000&task_name=00005041) [here](https://lhcb-productions.web.cern.ch/logs/?lfn=%2Flhcb%2FLHCb%2FCollision25%2FLOG%2F00335424%2F0000&task_name=00005027) [here](https://lhcb-productions.web.cern.ch/logs/?lfn=%2Flhcb%2FLHCb%2FCollision25%2FLOG%2F00335424%2F0000&task_name=00004018) | 3 / 3 |
|  | `LFN:/lhcb/LHCb/Collision25/B2OC.DST/00310455/0010/00310455_00100775_1.b2oc.dst` | 1218754724 | **LCG.IN2P3.fr** (3) | 3.4 GiB | [here](https://lhcb-productions.web.cern.ch/logs/?lfn=%2Flhcb%2FLHCb%2FCollision25%2FLOG%2F00335424%2F0000&task_name=00005041) [here](https://lhcb-productions.web.cern.ch/logs/?lfn=%2Flhcb%2FLHCb%2FCollision25%2FLOG%2F00335424%2F0000&task_name=00005027) [here](https://lhcb-productions.web.cern.ch/logs/?lfn=%2Flhcb%2FLHCb%2FCollision25%2FLOG%2F00335424%2F0000&task_name=00004018) | 3 / 3 |
|  | `LFN:/lhcb/LHCb/Collision25/B2OC.DST/00310455/0010/00310455_00100904_1.b2oc.dst` | 1218754724 | **LCG.IN2P3.fr** (3) | 3.4 GiB | [here](https://lhcb-productions.web.cern.ch/logs/?lfn=%2Flhcb%2FLHCb%2FCollision25%2FLOG%2F00335424%2F0000&task_name=00005041) [here](https://lhcb-productions.web.cern.ch/logs/?lfn=%2Flhcb%2FLHCb%2FCollision25%2FLOG%2F00335424%2F0000&task_name=00005027) [here](https://lhcb-productions.web.cern.ch/logs/?lfn=%2Flhcb%2FLHCb%2FCollision25%2FLOG%2F00335424%2F0000&task_name=00004018) | 3 / 3 |
|  | `LFN:/lhcb/LHCb/Collision25/B2OC.DST/00310455/0011/00310455_00118901_1.b2oc.dst` | 1218754724 | **LCG.IN2P3.fr** (3) | 3.4 GiB | [here](https://lhcb-productions.web.cern.ch/logs/?lfn=%2Flhcb%2FLHCb%2FCollision25%2FLOG%2F00335424%2F0000&task_name=00005041) [here](https://lhcb-productions.web.cern.ch/logs/?lfn=%2Flhcb%2FLHCb%2FCollision25%2FLOG%2F00335424%2F0000&task_name=00005027) [here](https://lhcb-productions.web.cern.ch/logs/?lfn=%2Flhcb%2FLHCb%2FCollision25%2FLOG%2F00335424%2F0000&task_name=00004018) | 3 / 3 |

### too_much_memory_for_cgroups in 1 LFNs

| Transform | LFN | Job ID | Site | Peak Mem | Log URL(s) | Occurrences |
| --------- | --- | ------ | ---- | -------- | ---------- | ----------- |
| `335424` | `LFN:/lhcb/LHCb/Collision25/B2OC.DST/00310455/0011/00310455_00118902_1.b2oc.dst` | 1218754724 | **LCG.IN2P3.fr** (3) | 3.4 GiB | [here](https://lhcb-productions.web.cern.ch/logs/?lfn=%2Flhcb%2FLHCb%2FCollision25%2FLOG%2F00335424%2F0000&task_name=00005041) [here](https://lhcb-productions.web.cern.ch/logs/?lfn=%2Flhcb%2FLHCb%2FCollision25%2FLOG%2F00335424%2F0000&task_name=00005027) [here](https://lhcb-productions.web.cern.ch/logs/?lfn=%2Flhcb%2FLHCb%2FCollision25%2FLOG%2F00335424%2F0000&task_name=00004018) | 3 / 3 |
